#  Copyright (C) 2024
#  ABM, Moscow
#
#  UNPUBLISHED PROPRIETARY MATERIAL.
#  ALL RIGHTS RESERVED.
#
#  Authors: Mikhail Mamrov <m.mamrov@abm-jsc.ru>
#
from detector_connector import DetectorConnector, DetectorAnalyzeResult

from pollution_detector_connector.pollution_settings import PollutionSettings


class PollutionDetectorConnector(DetectorConnector):
    Context = DetectorConnector.Context
    Config = DetectorConnector.Config

    def __init__(self, config: Config, context: Context) -> None:
        super().__init__(
            config=config,
            context=context,
            detector_analyze_result_type=DetectorAnalyzeResult,
            detector_settings_type=PollutionSettings,
        )
